#!/bin/bash
# google-earth-fonts-v0.2
# Marko Martinović (Marko-M), 2009
# Installation of Google Earth plus fix for ugly GUI fonts 

# "Press any key to continue" function.
function pause(){
   read -p "$*"
}

# Am I root? Must be root to do what we need to do,
if [ "$(whoami)" != "root" ]
			then		
			echo "Please call this script with root privileges."
			pause "Press any key to EXIT"
			exit 0
		fi

echo -e "\n\033[1mWellcome to Google Earth + GUIFontsFix installation script.\033[0m"

echo
echo -e "Google Earth for Linux comes with its own set of old Qt libraries. To match your distro look and feel it is necessary to link Google Earth with Qt libraries provided by your distribution. This script installs Google Earth if it's not already installed and does job of linking libraries for you. Follow the instructions."
pause "Press any key to begin"

echo

echo "This script will try to detect your distribution. Supported Linux distributions are:"
echo
echo "	1. Ubuntu 9.04 (Jaunty Jackalope) i686"
echo "	2. Ubuntu 9.04 (Jaunty Jackalope) x86_64"
echo "	3. Fedora 11 (Leonidas) i686"
echo "	4. Linux Mint 7 (Gloria) i686"
echo "	5. Linux Mint 7 (Gloria) x86_64"
echo

# Which distro is this? With distro detection there's no standard amognst Linux distros. Ubuntu uses /etc/lsb-release file with discription of the distribution. Fedora uses /etc/fedora-release. Which architecture is this? Detected using "uname -m".

MACH=$(uname -m)
# Distro identify code for Ubuntu based distros
if [ -f  /etc/lsb-release ]
	then
	distString=$(cat /etc/lsb-release)
	case "$distString" in 
	  *"Ubuntu 9.04"*)
		case "$MACH" in
			'i686')
			echo -e "\033[1mYour distribution is Ubuntu 9.04 (Jaunty Jackalope) i686.\033[0m"
			pause "Press any key to continue"
			distro=Ubu904x86
			qtver="4.5.0"
			qtpath="/usr/lib/"
			;;
			'x86_64')
			echo -e "\033[1mYour distribution is Ubuntu 9.04 (Jaunty Jackalope) x86_64.\033[0m"
			pause "Press any key to continue"
			distro=Ubu904x64
			qtver="4.5.0"
			qtpath="/usr/lib32/"
			;;
			*)
			echo -e "\033[1mSorry. Only x86 and x86_64 distributions of Ubuntu 9.04 are supported!\033[0m"
			pause "Press any key to EXIT"
			exit 0
			;;
		esac
	  ;;
	  *"Linux Mint 7"*)
		case "$MACH" in
			'i686')
			echo -e "\033[1mYour distribution is Linux Mint 7 (Gloria) i686.\033[0m"
			pause "Press any key to continue"
			distro=Mint7x86
			qtver="4.5.0"
			qtpath="/usr/lib/"
			;;
			'x86_64')
			echo -e "\033[1mYour distribution is Linux Mint 7 (Gloria) x86_64.\033[0m"
			echo -e "\033[1mYour distribution should be supported using Ubuntu 9.04 x86_64 code but it hasn't been confirmed. I you decide to proceed please contact community about how it went.\033[0m"
			pause "Press any key to continue or CTRL^C to abort!"
			distro=Mint7x64
			qtver="4.5.0"
			qtpath="/usr/lib32/"
			;;
			*)
			echo -e "\033[1mSorry. Only x86 and x86_64 distributions of Linux Mint 7 are supported!\033[0m"
			pause "Press any key to EXIT"
			exit 0
			;;
		esac
	  ;;
	  *)
	  	echo -e "\033[1mSorry. Your distribution is not supported!\033[0m"
		pause "Press any key to EXIT"
	  	exit 0
	  ;;
	esac
fi

#  Distro identify code for Fedora distros
if [ -f  /etc/fedora-release ]
	then
	distString=$(cat /etc/fedora-release)
	case "$distString" in 
	  *"Fedora release 11"*)
		case "$MACH" in
			'i686')
			echo -e "\033[1mYour distribution is Fedora 11 (Leonidas) i686.\\033[0m"
			pause "Press any key to continue"
			distro=Fed11x86
			qtver="4.5.2"
			qtpath="/usr/lib/"
			;;
			*)
			echo -e "\033[1mSorry. Only x86 distribution of Fedora 11 are supported!\033[0m"
			pause "Press any key to EXIT"
			exit 0
			;;
		esac
		
	  ;;
	  *)
	  	echo -e "\033[1mSorry. Your distribution is not supported!\033[0m"
		pause "Press any key to EXIT"
	  	exit 0
	  ;;
	esac
fi

echo

# Distro specific pre-install work (mostly install of required libs)
case "$distro" in
	'Ubu'*)
		echo "Doing system files update check..."
		apt-get update
		echo "Installing necessary packages..."
		case "$distro" in
			*'x86')
				echo "Installing Qt4 support..."
				apt-get -y install libqt4-core libqt4-gui libqt4-network libqt4-webkit
			;;
			*'x64')
				echo "Installing native 64-bit Qt4 support..."
				apt-get -y install apt-get install libqt4-core libqt4-gui libqt4-network libqt4-webkit
				echo "Installing 32-bit libraries support..."
				sudo apt-get install -y ia32-libs lib32nss-mdns
				echo "Downloading and installing \"getlibs\" script"
				cd /tmp
				wget http://frozenfox.freehostia.com/cappy/getlibs-all.deb && chmod +x getlibs-all.deb
				dpkg -i getlibs-all.deb
				rm getlibs-all.deb
				echo "Installing necessary 32-bit libs using \"getlibs\" script"
				getlibs -p libqt4-webkit --yes
				getlibs -p libphonon4 --yes
			;;
		esac
	;;
	'Min'*)
		echo "Doing system files update check..."
		apt-get update
		echo "Installing necessary packages..."
		case "$distro" in
			*'x86')
				echo "Installing Qt4 support..."
				apt-get -y install libqt4-core libqt4-gui libqt4-network libqt4-webkit
			;;
			*'x64')
				echo "Installing 64 bit Qt4 support..."
				apt-get -y install apt-get install libqt4-core libqt4-gui libqt4-network libqt4-webkit
				echo "Installing 32-bit libraries support..."
				sudo apt-get install -y ia32-libs lib32nss-mdns
				echo "Downloading and installing \"getlibs\" script"
				cd /tmp
				wget http://frozenfox.freehostia.com/cappy/getlibs-all.deb && chmod +x getlibs-all.deb
				dpkg -i getlibs-all.deb
				rm getlibs-all.deb
				echo "Installing necessary 32-bit libs using \"getlibs\" script"
				getlibs -p libqt4-webkit --yes
				getlibs -p libphonon4 --yes
			;;
		esac
	;;
	'Fed'*)
		echo "Doing system files update check..."
		yum -y update
		if [ -f  /etc/selinux/config ]
			then
			selin_string=$(cat /etc/selinux/config)
			case "$selin_string" in 
				*'SELINUX=enforcing'*)
					echo
					echo -e '\033[1mSELinux in enforcing mode detected!\033[0m'
					echo -e 'Using Google Earth with SELinux is not recommended.'
					echo 'Lets disable SELinux? [y] Yes, [n] No'
					read answer
					case "$answer" in
						'y')
						sed -i 's/SELINUX=enforcing/SELINUX=disabled/' /etc/selinux/config
						;;
						'n')
						echo "Skipping SELinux termination. You've been warned!"
						;;
						*)
						echo "You didn't pres \"y\" or \"n\". Skipping SELinux termination. You've been warned!"
						;;
					esac
				;;
			esac
		fi
		case "$distro" in
			*'x86')
				# Nothing to do. Space is here in case something comes up.
			;;
		esac
	;;
	*)
	;;
esac

echo

# Is Google Earth already installed? If it is, skip this.
if [ -d /opt/google-earth ]
	then
		echo "Google Earth is already installed. Continuing with GUIFontsFix."
	else		
		# Download and execution of installer
		echo -e "This script will now download Google Earth from Google server and start the installation. It is up to you to install Google Earth in its default location (/opt/google-earth) and \033[1mNOT TO CLICK \"START\" AT THE END OF THE INSTALLATION PROCESS!\033[0m"
		pause "Press any key to continue"

		echo
		echo "Waiting for Google Earth installation to finish..."

		cd /tmp
		wget http://dl.google.com/earth/client/current/GoogleEarthLinux.bin && chmod +x GoogleEarthLinux.bin
		./GoogleEarthLinux.bin
		echo
		echo -e "Please \033[1mQUIT\033[0m Google Earth if you accidentally started it. There is work to be done before starting Google Earth!"
		pause "Press any key to continue"
		rm GoogleEarthLinux.bin	
fi
echo
echo "Making Google Earth for Linux Qt libraries links..."

# Linking google-earth to systems Qt libraries
cd /opt/google-earth/
mv libQtCore.so.4 libQtCore.so.4.bak
mv libQtGui.so.4 libQtGui.so.4.bak
mv libQtNetwork.so.4 libQtNetwork.so.4.bak
mv libQtWebKit.so.4 libQtWebKit.so.4.bak
ln -s ${qtpath}libQtCore.so.$qtver libQtCore.so.4
ln -s ${qtpath}libQtGui.so.$qtver libQtGui.so.4
ln -s ${qtpath}libQtNetwork.so.$qtver libQtNetwork.so.4
ln -s ${qtpath}libQtWebKit.so.$qtver libQtWebKit.so.4

# Telling Google Earth where to look for Qt (fix for photos not shown after linking to system libraries)
echo -e "[PATHS]\nDocumentation=/usr/share/doc\nLibraries=${qtpath}\nPlugins=${qtpath}qt4/plugins\nTranslations=/usr/share/qt4/translation" > /opt/google-earth/qt.conf

echo
echo "It all went well! You can start Google Earth from Internet subsection of your desktop menu. Also now you can use qtconfig-qt4 to configure the font settings."
